using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;

namespace Jiraiya
{
    public class FridgeDoors : MVRScript
    {
        #region PluginInfo    
        public string pluginAuthor = "Jiraiya";
        public string pluginName = "Fridge Doors";
        public string pluginVersion = "1";
        public string pluginDate = "09/08" + "/2021";
        public string pluginDescription = @"Used to open and close the fridge doors";
        #endregion

        #region Vars    



        public GameObject player;
        public GameObject Ks_Fridge;

        protected JSONStorableFloat ScrubA;
        protected JSONStorableFloat ScrubB;
	protected JSONStorableFloat yRotation;
        protected JSONStorableFloat yRotation2;


        private float previousValue1;
        private float previousValue2;

        private float previousZValue;
        private float currentZValue;

	private string objectNameSearchString = "B_Daily_R_St_N_Electric_0002";
	public Transform ObjectRoot;
        public Transform topdoor;
        public Transform bottomdoor;

	private Renderer topdoorRenderer;
	private Renderer bottomdoorRenderer;

        private bool editorInitialized = false;
        private int initLoops = 0;
        private int maxInitLoops = 360; //3600 for one minute


        private static Atom currentAtom;
        private static string currentAtomName = "None";
        private static string tempAtomName = "None";

        #endregion

        public override void Init()
        {
            try
            {
		if (containingAtom.type != "CustomUnityAsset")
	                {
	                SuperController.LogError("FridgeDoor - Please add this script on a Custom Unity Asset ( script disabled).");
  	                return;
  		        }


                //**************  ScrubA
                ScrubA = new JSONStorableFloat("Top Door", 0f, -1.61f, 1.16f, true);
                RegisterFloat(ScrubA);
                CreateSlider(ScrubA, false);
                          

                //**************  ScrubB
                ScrubB = new JSONStorableFloat("Bottom Door", 0f, -1.61f, 1.16f, true);				
                RegisterFloat(ScrubB);
                CreateSlider(ScrubB, false);

              // A tiny bit of help to give some info to your fellow creator and/or player
                JSONStorableString helpText = new JSONStorableString("Help",
                    "<color=#000><size=35><b>Help</b></size></color>\n\n" +
                    "<color=#333>" +
                    "Simple script to allow you to set the door position for each of the fridge doors.\n\n" +
                    "Moving the two sliders wil change the open state of the each door individually.\n\n" +
                    "</color>" );
               UIDynamic helpTextfield = CreateTextField(helpText, true);
                helpTextfield.height = 1100.0f;

            }
            catch (Exception e)
            {
                SuperController.LogError("Exception caught: " + e);
            }
        }

        // Update is called with each rendered frame by Unity
        void Update()
        {
            var Slider1 = ScrubA.val;
            var Slider2 = ScrubB.val;

           if( initLoops < maxInitLoops && editorInitialized == false ) {
                initLoops++;
                InitEditor();
            }
	if( initLoops == maxInitLoops ) {
                SuperController.LogError("Fridgedoor : This CUA could not be initialized properly. Please select a compatible object and reload the script.");
                initLoops++; // To avoid spamming the log with the error
            }



            {


               if (previousValue1 != Slider1)
                {
                    OnSliderChanged();
                }

                if (previousValue2 != Slider2)
                {
                   OnSliderChanged2();
                }

            }

        }

        private bool InitEditor() {
            if( editorInitialized == true ) return true;
        
            ObjectRoot = getObjectRoot( containingAtom.reParentObject );
            if( ObjectRoot == null ) {
                return false;
            }
        
            topdoor = ObjectRoot.Find("B_Electric_0_007_1");
            bottomdoor = ObjectRoot.Find("B_Electric_0_007_2");
                
            // I found my transforms, now the rest
            if( topdoor && bottomdoor) {
                topdoorRenderer = topdoor.GetComponent<Renderer>();
                bottomdoorRenderer = bottomdoor.GetComponent<Renderer>();
            
                if( topdoorRenderer && bottomdoorRenderer ) {
                    editorInitialized = true;                           
                    return true;
                } else {
                    SuperController.LogError("Fridgedoor : error your CUA has a transform with the good name but does not have a renderer.");
                    initLoops = maxInitLoops; 
                    return false;
                }
            } else {
                SuperController.LogError("Fridgedoor : your CUA is missing mandatory components ( transform name cube and sphere ).");
                initLoops = maxInitLoops; // We don't have what we need, we consider the initialization failed
                return false;
            }
        
            return false;
        }

     private Transform getObjectRoot( Transform parent ) {
            foreach( Transform child in parent )
            {
                if( child.name.Contains(objectNameSearchString) ) {
                    return child;
                } else {
                    Transform childSearch = getObjectRoot(child);
                    if (childSearch != null) return childSearch;
                }
            }
        
            return null;
        }





        // Top Door
        void OnSliderChanged()
        {
            
            {

                var Slider1 = ScrubA.val;
                var a = Slider1 - previousValue1;
               topdoor.transform.Rotate(Vector3.back * a * 56);
               previousValue1 = ScrubA.val;
            }

        }

        // Bottom Door
        void OnSliderChanged2()
        {

            {

                var Slider2 = ScrubB.val;
                var a = Slider2 - previousValue2;
                bottomdoor.transform.Rotate(Vector3.back * a * 56);
                previousValue2 = ScrubB.val;
            }

        }


    }
}